#
# spec file for package terraform-provider-helm
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         hashicorp
%global repo            terraform-provider-helm
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global providername    helm

%ifarch aarch64
%define terraformarch   arm64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-helm
Version:        2.9.0
Release:        150200.6.8.1
Summary:        Terraform Helm provider
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-helm
Source:         %{name}-%{version}.tar.xz
Source101:      %{name}-rpmlintrc
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkgconfig
BuildRequires:  xz-utils
%else
# Terraform is not available for 32bit platforms
ExcludeArch:    %ix86 %arm
Requires:       terraform >= 0.13.0
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang-packaging
BuildRequires:  xz
BuildRequires:  golang(API) >= 1.13
%endif
%endif
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a Helm provider for Terraform.

The provider manages the installed Charts in your Kubernetes cluster, in the
same way of Helm does, through Terraform. It will also install Tiller
automatically if it is not already present.

%prep
%setup -q -n %{repo}-%{version}

%build
%{goprep} %{import_path}
%{gobuild} -mod=vendor ""

%install
%{goinstall}
rm -rf %{buildroot}/%{_libdir}/go/contrib
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Wed Feb 22 2023 adrian.glaubitz@suse.com
- Update to version 2.9.0
  * FEATURES:
    + provider: Add a new attribute burst_limit for client-side
    throttling limit configuration. [GH-1012]
  * ENHANCEMENT:
    + data_source/helm_template: Add a new attribute crds which when include_crds
    is set to true will be populated with a list of the manifests from the crds/
    folder of the chart. [GH-1050]
  * BUG FIXES:
    + resource/helm_release: Fix an issue when the provider crashes with the error
    message Provider produced inconsistent final plan after upgrading from v2.5.1
    to v2.6.0 and higher. That happened due to changes in the provider schema and
    the introduction of a new attribute pass_credentials that was not properly
    handled. [GH-982]
  * DOCS:
    + data_source/helm_template: Add a new attribute crds [GH-1050]
    + data_source/helm_template: Correct some errors in examples. [GH-1027]
    + provider: Add a new attribute burst_limit. [GH-1012]
    + provider: Add a note regarding the KUBECONFIG environment variable. [GH-1051]
    + resource/helm_release: Add usage example for OCI repositories. [GH-1030]
    + resource/helm_release: Add usage examples for GCS and S3 plugins. [GH-1026]
  * DEPENDENCIES:
    + Bump github.com/containerd/containerd from 1.6.6 to 1.6.12 [GH-1029]
    + Bump golang.org/x/crypto from 0.5.0 to 0.6.0 [GH-1055]
    + Bump helm.sh/helm/v3 from 3.9.4 to 3.11.1 [GH-1036] [GH-1054] (bsc#1208086, CVE-2023-25165)
    + Bump k8s.io/client-go from 0.24.2 to 0.26.1 [GH-1037]
  * NOTES:
    + provider: kubernetes.exec.api_version no longer supports client.authentication.k8s.io/v1alpha1.
    Please, switch to client.authentication.k8s.io/v1beta1 or client.authentication.k8s.io/v1. [GH-1037]
- from version 2.8.0
  * FEATURES:
    + Add support for configuring OCI registries inside provider block [GH-862]
    + Add support for setting kube version on helm_template data source [GH-994]
  * BUG FIXES:
    + Fix larger diff than expected when updating helm_release "set" block value [GH-915]
- from version 2.7.1
  * BUG FIXES:
    + Crash Fix: Fix Unknown Value in Manifest Diff [GH-966]
- from version 2.7.0
  * FEATURES:
    + Update helm package to 3.9.4 (#945)
    + Show Manifest when creating release [GH-903]
  * BUG FIXES:
    + Do dependency update in resourceDiff #771 (#855)
    + Crash: Fix show_only crash when string is empty [GH-950]
- from version 2.6.0
  * IMPROVEMENTS:
    + Upgrade helm dependency to 3.9.0 (#867)
    + Add args attribute in post_render block in (#869)
    + Add pass_credentials attribute (#841)
    + Add proxy_url attribute to provider block (#843)
  * BUG FIXES:
    + Don't persist state when update causes an error (#857)
- from version 2.5.1
  * FIX:
    + Only run OCI login on create and update (#846)
    + OCI login concurrency issue (#848)
- from version 2.5.0
  * IMPROVEMENTS:
    + Upgrade helm dependency to v3.8.1
  * FEATURES:
    + Add support for OCI registries
- from version 2.4.1
  * HOTFIX:
    + Fix exec plugin interactive mode regression (#798)
- from version 2.4.0
  * IMPROVEMENTS:
    + Update helm dependency to v3.7.1
  * FEATURES:
    + Add wait support to helm_release delete operation
- Fix terraform architecture mapping for aarch64
* Wed Mar 30 2022 dmueller@suse.com
- exclude build for 32bit targets
* Thu Jul 29 2021 adrian.glaubitz@suse.com
- Update to version 2.2.0
  * Add support for stand-alone debug mode (launch with -debug argument) (#748)
  * Add helm_template data source to render chart templates locally (#483)
  * Surface diagnostics when helm release creation fails (#727)
- from version 2.1.2
  * Fix dependency download on resource update (#580)
  * Add support for the --wait-for-jobs option (#720)
- from version 2.1.1
  * Fix dry-run happening at plan when manifest is not enabled (#724)
- from version 2.1.0
  IMPROVEMENTS:
  * Add chart diff support by storing the rendered manifest (#702)
  * Update to Helm 3.5.3 (#709)
  * Docs: add link to Learn tutorial (#714)
  BUG FIXES:
  * Remove kubeconfig file check (#708)
- from version 2.0.3
  BUG FIXES:
  * Fix documentation for KUBE_TOKEN env var name (#684)
  * Fix destroy stage error for charts with "helm.sh/resource-policy:keep" annotation (#671)
  * Fix read function to set resource id to null when not found (#674)
  IMPROVEMENTS:
  * Update provider configuration docs (#673)
- from version 2.0.2
  BUG FIXES:
  * Remove check for empty kubernetes block
- from version 2.0.1
  BUG FIXES:
  * Move kubernetes config check out of providerConfigure (#648)
* Mon Jan 18 2021 adrian.glaubitz@suse.com
- Update to version 2.0.0:
  * BREAKING CHANGES:
    + Update Terraform SDK to v2 (#594)
    + Remove deprecated helm_repository resource and data source (#600)
    + Remove implicit support for KUBECONFIG (#604)
    + Remove load_config_file attribute (#604)
    + Remove set_string attribute from helm_release (#608)
  * IMPROVEMENTS:
    + Add support for multiple paths to kubeconfig files (#636)
    + Remove remote dependencies from test-fixtures (#638)
    + Set up matrix build to run acc tests against different tf versions (#637)
* Wed Nov 11 2020 adrian.glaubitz@suse.com
- Add symbolic link to comply with new filesystem layout for local provider copies
- Define and use common Go spec file variables
* Mon Oct 19 2020 adrian.glaubitz@suse.com
- Update to version 1.3.2:
  * Update pull request docs
  * Create codeql-analysis.yml (#597)
  * Update CHANGELOG
  * Fix nil pointer crash when using plugins (#598)
- from version 1.3.1
  * Update CHANGELOG for v1.3.1
  * Upgrade to helm 3.3.4 (#572)
  * Fix website tests (#590)
- from version 1.3.0
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * Update pull_request_template.md
  * Added app_version to metadata attribute block (#532)
  * Fix nil path for dependency_update flag (#482)
  * Update config.yml
  * Update docs for verify and chart attributes in helm_release (#565)
  * Update CONTRIBUTING.md
  * Update README.md
  * Extend staleness check to 365 days from 180 days
  * Cleanup after v1.2.4 release
* Tue Aug 11 2020 adrian.glaubitz@suse.com
- Update to version 1.2.4:
  * Update go-version for CVE-2020-14039 (#548)
  * Add Q3 2020 roadmap (#545)
  * Added note on NOTES.txt to FAQ (#518)
  * Fix typo in helm_release documentation (#538)
  * Update labeled_issues.yml
  * Update 'helm_release' resource docs to have information about the optional type parameter configured within set and set_sensitive blocks. (#499)
  * Fix: avoid concurrent read/write in metadata (#494) (#525)
  * disable writing to stderr with klog (#505)
  * Update README.md
  * Replace all instances of the old org with the new one (#522)
  * Cleanup after v0.10.5 release
  * Update various links bots after migration (#521)
  * Improve readme (#511)
  * Put helm lint behind an attribute (#514)
  * Add more meaningful deprecation warning to helm_repository (#491)
  * Fix crash when chart fails linter (#487)
  * Add go report card badge
  * Add actions badge to README.md
  * Move PR tests to GitHub Actions (#488)
  * vendor: add package github.com/hashicorp/terraform-plugin-sdk/helper
  * helm_release: cloak metadata.value and deprecate set_string
  * Helm v3.2.0 (#477)
  * Fix token name
  * Add issue pruning tasks
  * Add exec block documentation (#469)
  * helm_repository: deprecated
  * helm_release: chart lint when `terraform plan`
  * Update issue templates
  * Add github actions for issues+PRs
  * Fix repo/chart path bug causing unexpected diff (#449)
  * Use kind to run acceptance tests in travis-ci (#407)
  * Example with chart not in repository (#442)
  * Upgrade helm to v3.1.2 (#440)
  * Helm v3 import release feature (#394)
  * Helm v3.1.1 (#410)
  * Fix install errors being swallowed when creating a helm_release (#406)
  * Add timeout flag details (#421)
  * Fix no HCL highlighting on helm_release docs
  * Fix broken link in README.md
  * Fix bullet points on provider configuration (#395)
  * Upgrade to go v1.13 (#356)
  * Fix typo in README.md
  * Documentation updates for Helm 3 (#393)
  * Updating plugin to use helm version 3 (#378)
  * Fix test infra on GKE
  * :book: Update Github issue template
  * Update documentation additional description of CLI equivalent.
  * Update documentation describing optional 'disabled_crd_hooks' flag.
  * Change description as per @jakesyl suggestion
  * set default timeout to 60 seconds instead of 5, which seems to be too low
  * set connection_timeout parameter
  * update website docs folder structure
  * Cleanup after v0.10.4 release
  * Add flag disable_crd_hooks which allows use to use the same --no-crd-hook offered via the command line helm.
* Thu Apr 30 2020 james.mason@suse.com
- Update to version 1.0.0 (bsc#1168921):
  * Upgrade to go v1.13 (#356)
  * Updating plugin to use helm version 3 (#378)
* Wed Mar  4 2020 rjschwei@suse.com
- Spec clean up
- Create required symlink
* Fri Feb  7 2020 rjschwei@suse.com
- Create symlink for terraform to recognize the provider. See
  https://www.terraform.io/docs/extend/how-terraform-works.html#plugin-locations
* Wed Feb  5 2020 adrian.glaubitz@suse.com
- Initial build
  + Version 0.10.4
